##############################################################################
#
# Copyright (c) 2006-2009 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

from zope.component.hooks import getSite
from grokcore.component import *
from grokcore.site.directive import site, local_utility, install_on
from grokcore.site.components import Site, LocalUtility, Application
from grokcore.site.util import getApplication

import grokcore.site.testing

from grokcore.site.interfaces import IApplication
from grokcore.site.interfaces import IApplicationAddedEvent
from grokcore.site.interfaces import ApplicationAddedEvent

from grokcore.site.interfaces import IGrokcoreSiteAPI
__all__ = list(IGrokcoreSiteAPI)
